@@ -5,5 +5,5 @@ class ThreadItem:
     """Class to define a thread's name, start time, and decimals."""
 
     name: str
-    start_time: str
+    start_time: int
     decimals: int
